# Oracle Linux

This repository provides tips, scripts, tools, and examples for developers and operators to get started with Oracle Linux.

## Getting started with Oracle Linux

### Download Oracle Linux
- Download [Oracle Linux binary and source media for x86_64 and Arm (aarch64) architectures](http://yum.oracle.com/oracle-linux-isos.html).
- [Download Oracle Linux for Raspberry Pi](https://www.oracle.com/linux/downloads/linux-arm-downloads.html).
- Download individual packages and updates from [Oracle Linux yum server](https://yum.oracle.com).

### Convert CentOS to Oracle Linux
Looking to switch from CentOS to Oracle Linux? Head over to the [centos2ol repo](https://github.com/oracle/centos2ol) for a script designed to automatically switch a CentOS instance to Oracle Linux.

### Help

 - The [Issues](https://github.com/oracle/oracle-linux/issues) section of this GitHub repository
 - [Stackoverflow](https://stackoverflow.com). Use the [oraclelinux](https://stackoverflow.com/questions/tagged/oraclelinux) tag.
 - [Oracle Linux topic](https://community.oracle.com/tech/apps-infra/categories/oracle_linux) on Oracle Communities
 - [Linux topic](https://community.oracle.com/customerconnect/categories/oci-cloud-infrastructure-linux) on Cloud Customer Connect
 - [My Oracle Support](https://support.oracle.com)

### Container images
 - Download official Oracle Linux base images published on [GitHub Container Registry](https://github.com/orgs/oracle/packages/container/package/oraclelinux).
 - Download [developer-oriented images](https://github.com/orgs/oracle/packages?repo_name=docker-images) to run your application code and or connect to Oracle Database
 - Build your own container images for Oracle commercial products and Oracle sponsored open source projects using these [sample Dockerfiles](https://github.com/oracle/docker-images).

### Vagrant boxes and projects
- [Download Oracle Linux Vagrant boxes](https://yum.oracle.com/boxes/)
- Explore [Vagrant projects](https://github.com/oracle/vagrant-projects) that provision Oracle and other software automatically 

### Build your own Oracle Linux images
Need to build custom Linux images for VirtualBox, KVM, Oracle Cloud or other clouds? See these [scripts to build Oracle Linux images](oracle-linux-image-tools)

### Explore Oracle Cloud Infrastructure SDK and CLI examples
- [Oracle Cloud Infrastructure provisioning shell script using the OCI Command Line Interface](oci-provision)
- [Oracle Cloud Infrastructure provisioning python script using the OCI Python SDK](oci-compute)


### Create your own RPMs
Learn recommended practices for [creating RPM packages for your software](creating-rpm-packages/creating-rpm-packages.md).


### Learn how to use Oracle Linux
* [Oracle Linux 8 tutorials](https://docs.oracle.com/en/operating-systems/oracle-linux/8/tutorials.html)
* [Oracle Linux 8 learning paths](https://www.oracle.com/goto/oraclelinuxlearningpath)
* [Oracle Linux 8 hands-on labs](https://luna.oracle.com/team/418f9969-5e1c-4bbb-ae5f-b8b6acffc9f1)(login required)


### View Unbreakable Enterprise Kernel source code
See the [source code for UEK](https://github.com/oracle/linux-uek), including every patch.

### Read the documentation
- [Oracle Linux documentation home](https://docs.oracle.com/en/operating-systems/oracle-linux/index.html).

## Contributing

This project welcomes contributions from the community. Before submitting a pull request, please [review our contribution guide](./CONTRIBUTING.md)

## Security

Please consult the [security guide](./SECURITY.md) for our responsible security vulnerability disclosure process

## License

Copyright (c) 2019, 2023 Oracle and/or its affiliates.

Released under the Universal Permissive License v1.0 as shown at
<https://oss.oracle.com/licenses/upl/>.
